/* 
Originally created by Lavinia Poruschi
Purpose of the program:											
Stata program to analyse an unbalanced longitudinal file  		 	 


*/

clear
clear matrix
clear mata
set maxvar 30000
* #delimit;

set more off
capture log close
set logtype text
global resultsdir = "C:\Publicatii\2016-05-RE_PV\Analysis\StataFiles\Results"
global datadir = "C:\Publicatii\2016-05-RE_PV\Analysis\StataFiles"
log using "$resultsdir\log_PV_analysis.txt", replace

use "$datadir\longfile_unbalanced_PVs.dta"
sort postcode year 

* Descriptives
xtsum lnPV lnPVL1 BuiltEnv FiTpremium FiTminimum lnIncome year2001-year2015
collin lnPVD1 lnPVL1D1 FiTpremiumD1 FiTminimumD1 BuiltEnvD1 lnIncomeD1 year2004-year2015

*** Diagnostic tests
*Autocorrelation
xtserial lnPV BuiltEnv FiTpremium FiTminimum lnIncome year2004-year2015

*LSDV
char _dta[omit] "prevalent"
xi: regress lnPV lnPVL1 BuiltEnv FiTpremium FiTminimum lnIncome year2004-year2015 i.postcode
display "the adjusted R-squared is: `e(r2_a)'
testparm _Ipostcode_*

*** Short-run analysis
eststo: xtabond2 lnPV lnPVL1 BuiltEnv FiTpremium FiTminimum lnIncome year2004-year2015, gmm(lnPVL1, lag(6 7) c) gmm(FiTpremium, lag(3 3) c) gmm(FiTminimum, lag(1 1) c) gmm(BuiltEnv, lag(1 2) c)   gmm(lnIncome, lag(3 3) c)  ivstyle(year2004-year2015) noleveleq orthogonal twostep small robust artests(3)
esttab using "$resultsdir\panel_PV.rtf ", replace b(4) se(4) star(* 0.10 ** 0.05 *** 0.01) scalars(N N_g F F_p j gmm1 ar1p ar2p ar3p sarganp hansenp) onecell pa rtf
eststo clear

quietly xtabond2 lnPV lnPVL1 BuiltEnv FiTpremium FiTminimum lnIncome year2004-year2015, gmm(lnPVL1, lag(6 7) c) gmm(FiTpremium, lag(3 3) c) gmm(FiTminimum, lag(1 1) c) gmm(BuiltEnv, lag(1 2) c)   gmm(lnIncome, lag(3 3) c)  ivstyle(year2004-year2015) noleveleq orthogonal twostep small robust artests(3)

*** Long-run analysis
* Built environment
eststo: nlcom _b[BuiltEnv]/(1-_b[lnPVL1])
* Feed-in tariffs
eststo: nlcom _b[FiTpremium]/(1-_b[lnPVL1])
eststo: nlcom _b[FiTminimum]/(1-_b[lnPVL1])
* Income
eststo: nlcom _b[lnIncome]/(1-_b[lnPVL1])

esttab using "$resultsdir\long-run_effects.rtf ", replace b(4) se(4) star(* 0.10 ** 0.05 *** 0.01) scalars(p) onecell pa rtf
eststo clear

log close
